Rietveld Code Review Tool
Help | Bug tracker | Discussion group | Source code | Sign in
(136)

Unified Diff: src/lte/model/lte-interference.h

Issue 130130043: GSoC 2014 LTE FFR algorithms project
Patch Set: Created 9 years, 7 months ago
Use n/p to move between diff chunks; N/P to move between comments. Please Sign in to add in-line comments.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: src/lte/model/lte-interference.h
===================================================================
--- a/src/lte/model/lte-interference.h
+++ b/src/lte/model/lte-interference.h
@@ -34,7 +34,7 @@
-class LteSinrChunkProcessor;
+class LteChunkProcessor;
@@ -54,31 +54,31 @@
virtual void DoDispose ();
/**
* Add a LteSinrChunkProcessor that will use the time-vs-frequency SINR
* calculated by this LteInterference instance. Note that all the
- * added LteSinrChunkProcessors will work in parallel.
+ * added LteChunkProcessors will work in parallel.
*
* @param p
*/
- void AddSinrChunkProcessor (Ptr<LteSinrChunkProcessor> p);
+ void AddSinrChunkProcessor (Ptr<LteChunkProcessor> p);
/**
* Add a LteSinrChunkProcessor that will use the time-vs-frequency
* interference calculated by this LteInterference instance. Note
- * that all the added LteSinrChunkProcessors will work in parallel.
+ * that all the added LteChunkProcessors will work in parallel.
*
* @param p
*/
- void AddInterferenceChunkProcessor (Ptr<LteSinrChunkProcessor> p);
+ void AddInterferenceChunkProcessor (Ptr<LteChunkProcessor> p);
/**
* Add a LteSinrChunkProcessor that will use the time-vs-frequency
* power calculated by this LteInterference instance. Note
- * that all the added LteSinrChunkProcessors will work in parallel.
+ * that all the added LteChunkProcessors will work in parallel.
*
* @param p
*/
- void AddRsPowerChunkProcessor (Ptr<LteSinrChunkProcessor> p);
+ void AddRsPowerChunkProcessor (Ptr<LteChunkProcessor> p);
/**
* notify that the PHY is starting a RX attempt
@@ -143,15 +143,15 @@
/** all the processor instances that need to be notified whenever
a new interference chunk is calculated */
- std::list<Ptr<LteSinrChunkProcessor> > m_rsPowerChunkProcessorList;
+ std::list<Ptr<LteChunkProcessor> > m_rsPowerChunkProcessorList;
/** all the processor instances that need to be notified whenever
a new SINR chunk is calculated */
- std::list<Ptr<LteSinrChunkProcessor> > m_sinrChunkProcessorList;
+ std::list<Ptr<LteChunkProcessor> > m_sinrChunkProcessorList;
/** all the processor instances that need to be notified whenever
a new interference chunk is calculated */
- std::list<Ptr<LteSinrChunkProcessor> > m_interfChunkProcessorList;
+ std::list<Ptr<LteChunkProcessor> > m_interfChunkProcessorList;
};

Powered by Google App Engine
@@ -54,31 +54,31 @@
virtual void DoDispose ();
/**
- * Add a LteSinrChunkProcessor that will use the time-vs-frequency SINR
+ * Add a LteChunkProcessor that will use the time-vs-frequency SINR
* calculated by this LteInterference instance. Note that all the
@@ -54,31 +54,31 @@
/**
- * Add a LteSinrChunkProcessor that will use the time-vs-frequency
+ * Add a LteChunkProcessor that will use the time-vs-frequency
* interference calculated by this LteInterference instance. Note
@@ -54,31 +54,31 @@
/**
- * Add a LteSinrChunkProcessor that will use the time-vs-frequency
+ * Add a LteChunkProcessor that will use the time-vs-frequency
* power calculated by this LteInterference instance. Note
RSS Feeds Recent Issues | This issue
This is Rietveld f62528b